summaryrefslogtreecommitdiffstats
path: root/parameter/FormattedSubsystemObject.h
diff options
context:
space:
mode:
authorFrançois Gaffie <francois.gaffie@intel.com>2016-02-17 10:58:44 +0100
committerEric Laurent <elaurent@google.com>2016-03-04 17:42:09 -0800
commit9368eea42a1afb01dd44110582f997115b50e742 (patch)
tree5efc2015ec5d52fc32453ad5a1a82a3f4a6b4919 /parameter/FormattedSubsystemObject.h
parent0efdadfc1eacc7271c8f854a8a610fdc2cc66102 (diff)
downloadplatform_external_parameter-framework-9368eea42a1afb01dd44110582f997115b50e742.tar.gz
platform_external_parameter-framework-9368eea42a1afb01dd44110582f997115b50e742.tar.bz2
platform_external_parameter-framework-9368eea42a1afb01dd44110582f997115b50e742.zip
parameter-framework: Drop of github upstream version v3.2.4
Main features are: -Networking code may now be opted-out (for android build: no socket opened for user build) -Get rid of python prebuild for XML generation Bug: 22887211 Change-Id: Ieee49b439f694f14ce48c23127d34622691397ef Signed-off-by: François Gaffie <francois.gaffie@intel.com> Signed-off-by: David Wagner <david.wagner@intel.com>
Diffstat (limited to 'parameter/FormattedSubsystemObject.h')
-rw-r--r--parameter/FormattedSubsystemObject.h47
1 files changed, 25 insertions, 22 deletions
diff --git a/parameter/FormattedSubsystemObject.h b/parameter/FormattedSubsystemObject.h
index c04583b..4793635 100644
--- a/parameter/FormattedSubsystemObject.h
+++ b/parameter/FormattedSubsystemObject.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2011-2014, Intel Corporation
+ * Copyright (c) 2011-2015, Intel Corporation
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
@@ -29,44 +29,49 @@
*/
#pragma once
+#include "parameter_export.h"
+
#include "SubsystemObject.h"
-class CFormattedSubsystemObject : public CSubsystemObject
+class PARAMETER_EXPORT CFormattedSubsystemObject : public CSubsystemObject
{
public:
/**
* Builds a new CFormattedSubsystemObject instance, without any mapping information.
*
* @param[in] pInstanceConfigurableElement Instance of the element linked to the SubsytemObject.
+ * @param[in] logger the logger provided by the client
*/
- CFormattedSubsystemObject(CInstanceConfigurableElement* pInstanceConfigurableElement);
+ CFormattedSubsystemObject(CInstanceConfigurableElement *pInstanceConfigurableElement,
+ core::log::Logger &logger);
/**
* Builds a new CFormattedSubsystemObject instance, using a simple mapping value without Amends.
*
* @param[in] pInstanceConfigurableElement Instance of the element linked to the SubsytemObject.
+ * @param[in] logger the logger provided by the client
* @param[in] strFormattedMapping A std::string corresponding to the mapping of the element. The
* std::string does not contain any Amend (%) and does not need to be formatted.
*/
- CFormattedSubsystemObject(CInstanceConfigurableElement* pInstanceConfigurableElement,
- const std::string& strFormattedMapping);
+ CFormattedSubsystemObject(CInstanceConfigurableElement *pInstanceConfigurableElement,
+ core::log::Logger &logger, const std::string &strFormattedMapping);
/**
* Builds a new CFormattedSubsystemObject instance, using a mapping value containing Amends.
*
* @param[in] pInstanceConfigurableElement Instance of the element linked to the SubsytemObject.
+ * @param[in] logger the logger provided by the client
* @param[in] strMappingValue A std::string corresponding to the mapping of the element. The
* std::string contains Amend (%) and needs to be formatted with information from the context.
* @param[in] uiFirstAmendKey Index of the first Amend key
* @param[in] uiNbAmendKeys Number of Amends
* @param[in] context Contains values associated to Amend keys
*/
- CFormattedSubsystemObject(CInstanceConfigurableElement* pInstanceConfigurableElement,
- const std::string& strMappingValue,
- uint32_t uiFirstAmendKey,
- uint32_t uiNbAmendKeys,
- const CMappingContext& context);
- virtual ~CFormattedSubsystemObject();
+ CFormattedSubsystemObject(CInstanceConfigurableElement *pInstanceConfigurableElement,
+ core::log::Logger &logger, const std::string &strMappingValue,
+ size_t firstAmendKey, size_t nbAmendKeys,
+ const CMappingContext &context);
+ virtual ~CFormattedSubsystemObject() = default;
/**
* Returns the formatted mapping value associated to the element.
@@ -76,7 +81,6 @@ public:
virtual std::string getFormattedMappingValue() const;
private:
-
/**
* Check if the index of Amend key is valid.
*
@@ -84,7 +88,7 @@ private:
*
* @return true if the index of the Amend key is > 0 and <= 9.
*/
- static bool isAmendKeyValid(uint32_t uiAmendKey);
+ static bool isAmendKeyValid(size_t uiAmendKey);
/**
* Generic mapping formatting
@@ -92,18 +96,17 @@ private:
* Format a std::string from mapping data and its context, replacing amendments by their value
*
* @param[in] strMappingValue The input mapping std::string containing amendments
* @param[in] context uiFirstAmendKey The index of the first Amend key in the key list of the
* context
* @param[in] uiNbAmendKeys Number of Amend keys in the context
* @param[in] context The context containing Amend values
*
- * @return The formatted std::string, corresponding to the input strMappingValue where %n have been
+ * @return The formatted std::string, corresponding to the input strMappingValue where %n have
+ * been
* replaced by their value
*/
- static std::string formatMappingValue(const std::string& strMappingValue,
- uint32_t uiFirstAmendKey,
- uint32_t uiNbAmendKeys,
- const CMappingContext& context);
+ static std::string formatMappingValue(const std::string &strMappingValue, size_t firstAmendKey,
+ size_t nbAmendKeys, const CMappingContext &context);
/**
* std::string containing the formatted mapping value
@@ -29,44 +29,49 @@
* @param[in] strMappingValue A std::string corresponding to the mapping of the element. The
* std::string contains Amend (%) and needs to be formatted with information from the context.
- * @param[in] uiFirstAmendKey Index of the first Amend key
- * @param[in] uiNbAmendKeys Number of Amends
+ * @param[in] firstAmendKey Index of the first Amend key
+ * @param[in] nbAmendKeys Number of Amends
* @param[in] context Contains values associated to Amend keys
*/
@@ -92,18 +96,17 @@ private:
*
* @param[in] strMappingValue The input mapping std::string containing amendments
- * @param[in] context uiFirstAmendKey The index of the first Amend key in the key list of the
+ * @param[in] context firstAmendKey The index of the first Amend key in the key list of the
* context
@@ -92,18 +96,17 @@ private:
* context
- * @param[in] uiNbAmendKeys Number of Amend keys in the context
+ * @param[in] nbAmendKeys Number of Amend keys in the context
* @param[in] context The context containing Amend values
*